import {ZObject, Bundle, HttpRequestOptions} from 'zapier-platform-core'

const {HOOKS_API_URL} = process.env

export function getRestHookOperations(eventName: string, sample: any) {
	return {
		type: 'hook',

		performSubscribe: async (zapier: ZObject, bundle: Bundle) => {
			const data = {
				url: bundle.targetUrl,
				event: eventName
			}

			const options: HttpRequestOptions & {url: string} = {
				url: `${HOOKS_API_URL}/hooks`,
				method: 'POST',
				body: data
			}

			return (await zapier.request(options)).json
		},

		performUnsubscribe: async (zapier: ZObject, bundle: Bundle) => {
			const hookId = (bundle as any).subscribeData.id

			const options: HttpRequestOptions & {url: string} = {
				url: `${HOOKS_API_URL}/hooks/${hookId}`,
				method: 'DELETE'
			}

			const response = await zapier.request(options)

			return response.content
		},

		perform: (zapier: ZObject, bundle: Bundle) => {
			if (!bundle.cleanedRequest) {
				return
			}

			return [(bundle.cleanedRequest as object[])[0]]
		},

		performList: (zapier: ZObject, bundle: Bundle) => {
			return [sample]
		},

		sample
	}
}
